"""Raw representations of every data type in the AWS Greengrass service.

See Also:
    `AWS developer guide for Greengrass
    <https://docs.aws.amazon.com/greengrass/latest/developerguide/what-is-gg.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "ConnectorDefinition",
    "ConnectorDefinitionProperties",
    "ConnectorDefinitionVersion",
    "ConnectorDefinitionVersionProperties",
    "CoreDefinition",
    "CoreDefinitionProperties",
    "CoreDefinitionVersion",
    "CoreDefinitionVersionProperties",
    "DeviceDefinition",
    "DeviceDefinitionProperties",
    "DeviceDefinitionVersion",
    "DeviceDefinitionVersionProperties",
    "FunctionDefinition",
    "FunctionDefinitionProperties",
    "FunctionDefinitionVersion",
    "FunctionDefinitionVersionProperties",
    "Group",
    "GroupProperties",
    "GroupVersion",
    "GroupVersionProperties",
    "LoggerDefinition",
    "LoggerDefinitionProperties",
    "LoggerDefinitionVersion",
    "LoggerDefinitionVersionProperties",
    "ResourceDefinition",
    "ResourceDefinitionProperties",
    "ResourceDefinitionVersion",
    "ResourceDefinitionVersionProperties",
    "SubscriptionDefinition",
    "SubscriptionDefinitionProperties",
    "SubscriptionDefinitionVersion",
    "SubscriptionDefinitionVersionProperties",
]


@attrs(**ATTRSCONFIG)
class ConnectorDefinitionProperties(ResourceProperties):
    InitialVersion = attrib(default=None)
    Name = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ConnectorDefinition(Resource):
    """A Connector Definition for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for ConnectorDefinition
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-connectordefinition.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::ConnectorDefinition"

    Properties: ConnectorDefinitionProperties = attrib(
        factory=ConnectorDefinitionProperties,
        converter=create_object_converter(ConnectorDefinitionProperties),
    )


@attrs(**ATTRSCONFIG)
class ConnectorDefinitionVersionProperties(ResourceProperties):
    ConnectorDefinitionId = attrib(default=None)
    Connectors = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ConnectorDefinitionVersion(Resource):
    """A Connector Definition Version for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for ConnectorDefinitionVersion
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-connectordefinitionversion.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::ConnectorDefinitionVersion"

    Properties: ConnectorDefinitionVersionProperties = attrib(
        factory=ConnectorDefinitionVersionProperties,
        converter=create_object_converter(ConnectorDefinitionVersionProperties),
    )


@attrs(**ATTRSCONFIG)
class CoreDefinitionProperties(ResourceProperties):
    InitialVersion = attrib(default=None)
    Name = attrib(default=None)


@attrs(**ATTRSCONFIG)
class CoreDefinition(Resource):
    """A Core Definition for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for CoreDefinition
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-coredefinition.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::CoreDefinition"

    Properties: CoreDefinitionProperties = attrib(
        factory=CoreDefinitionProperties,
        converter=create_object_converter(CoreDefinitionProperties),
    )


@attrs(**ATTRSCONFIG)
class CoreDefinitionVersionProperties(ResourceProperties):
    CoreDefinitionId = attrib(default=None)
    Cores = attrib(default=None)


@attrs(**ATTRSCONFIG)
class CoreDefinitionVersion(Resource):
    """A Core Definition Version for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for CoreDefinitionVersion
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-coredefinitionversion.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::CoreDefinitionVersion"

    Properties: CoreDefinitionVersionProperties = attrib(
        factory=CoreDefinitionVersionProperties,
        converter=create_object_converter(CoreDefinitionVersionProperties),
    )


@attrs(**ATTRSCONFIG)
class DeviceDefinitionProperties(ResourceProperties):
    InitialVersion = attrib(default=None)
    Name = attrib(default=None)


@attrs(**ATTRSCONFIG)
class DeviceDefinition(Resource):
    """A Device Definition for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for DeviceDefinition
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-devicedefinition.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::DeviceDefinition"

    Properties: DeviceDefinitionProperties = attrib(
        factory=DeviceDefinitionProperties,
        converter=create_object_converter(DeviceDefinitionProperties),
    )


@attrs(**ATTRSCONFIG)
class DeviceDefinitionVersionProperties(ResourceProperties):
    DeviceDefinitionId = attrib(default=None)
    Devices = attrib(default=None)


@attrs(**ATTRSCONFIG)
class DeviceDefinitionVersion(Resource):
    """A Device Definition Version for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for DeviceDefinitionVersion
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-devicedefinitionversion.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::DeviceDefinitionVersion"

    Properties: DeviceDefinitionVersionProperties = attrib(
        factory=DeviceDefinitionVersionProperties,
        converter=create_object_converter(DeviceDefinitionVersionProperties),
    )


@attrs(**ATTRSCONFIG)
class FunctionDefinitionProperties(ResourceProperties):
    InitialVersion = attrib(default=None)
    Name = attrib(default=None)


@attrs(**ATTRSCONFIG)
class FunctionDefinition(Resource):
    """A Function Definition for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for FunctionDefinition
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-functiondefinition.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::FunctionDefinition"

    Properties: FunctionDefinitionProperties = attrib(
        factory=FunctionDefinitionProperties,
        converter=create_object_converter(FunctionDefinitionProperties),
    )


@attrs(**ATTRSCONFIG)
class FunctionDefinitionVersionProperties(ResourceProperties):
    DefaultConfig = attrib(default=None)
    FunctionDefinitionId = attrib(default=None)
    Functions = attrib(default=None)


@attrs(**ATTRSCONFIG)
class FunctionDefinitionVersion(Resource):
    """A Function Definition Version for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for FunctionDefinitionVersion
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-functiondefinitionversion.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::FunctionDefinitionVersion"

    Properties: FunctionDefinitionVersionProperties = attrib(
        factory=FunctionDefinitionVersionProperties,
        converter=create_object_converter(FunctionDefinitionVersionProperties),
    )


@attrs(**ATTRSCONFIG)
class GroupProperties(ResourceProperties):
    InitialVersion = attrib(default=None)
    Name = attrib(default=None)
    RoleArn = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Group(Resource):
    """A Group for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for Group
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-group.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::Group"

    Properties: GroupProperties = attrib(
        factory=GroupProperties, converter=create_object_converter(GroupProperties)
    )


@attrs(**ATTRSCONFIG)
class GroupVersionProperties(ResourceProperties):
    ConnectorDefinitionVersionArn = attrib(default=None)
    CoreDefinitionVersionArn = attrib(default=None)
    DeviceDefinitionVersionArn = attrib(default=None)
    FunctionDefinitionVersionArn = attrib(default=None)
    GroupId = attrib(default=None)
    LoggerDefinitionVersionArn = attrib(default=None)
    ResourceDefinitionVersionArn = attrib(default=None)
    SubscriptionDefinitionVersionArn = attrib(default=None)


@attrs(**ATTRSCONFIG)
class GroupVersion(Resource):
    """A Group Version for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for GroupVersion
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-groupversion.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::GroupVersion"

    Properties: GroupVersionProperties = attrib(
        factory=GroupVersionProperties,
        converter=create_object_converter(GroupVersionProperties),
    )


@attrs(**ATTRSCONFIG)
class LoggerDefinitionProperties(ResourceProperties):
    InitialVersion = attrib(default=None)
    Name = attrib(default=None)


@attrs(**ATTRSCONFIG)
class LoggerDefinition(Resource):
    """A Logger Definition for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for LoggerDefinition
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-loggerdefinition.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::LoggerDefinition"

    Properties: LoggerDefinitionProperties = attrib(
        factory=LoggerDefinitionProperties,
        converter=create_object_converter(LoggerDefinitionProperties),
    )


@attrs(**ATTRSCONFIG)
class LoggerDefinitionVersionProperties(ResourceProperties):
    LoggerDefinitionId = attrib(default=None)
    Loggers = attrib(default=None)


@attrs(**ATTRSCONFIG)
class LoggerDefinitionVersion(Resource):
    """A Logger Definition Version for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for LoggerDefinitionVersion
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-loggerdefinitionversion.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::LoggerDefinitionVersion"

    Properties: LoggerDefinitionVersionProperties = attrib(
        factory=LoggerDefinitionVersionProperties,
        converter=create_object_converter(LoggerDefinitionVersionProperties),
    )


@attrs(**ATTRSCONFIG)
class ResourceDefinitionProperties(ResourceProperties):
    InitialVersion = attrib(default=None)
    Name = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ResourceDefinition(Resource):
    """A Resource Definition for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for ResourceDefinition
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-resourcedefinition.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::ResourceDefinition"

    Properties: ResourceDefinitionProperties = attrib(
        factory=ResourceDefinitionProperties,
        converter=create_object_converter(ResourceDefinitionProperties),
    )


@attrs(**ATTRSCONFIG)
class ResourceDefinitionVersionProperties(ResourceProperties):
    ResourceDefinitionId = attrib(default=None)
    Resources = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ResourceDefinitionVersion(Resource):
    """A Resource Definition Version for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for ResourceDefinitionVersion
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-resourcedefinitionversion.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::ResourceDefinitionVersion"

    Properties: ResourceDefinitionVersionProperties = attrib(
        factory=ResourceDefinitionVersionProperties,
        converter=create_object_converter(ResourceDefinitionVersionProperties),
    )


@attrs(**ATTRSCONFIG)
class SubscriptionDefinitionProperties(ResourceProperties):
    InitialVersion = attrib(default=None)
    Name = attrib(default=None)


@attrs(**ATTRSCONFIG)
class SubscriptionDefinition(Resource):
    """A Subscription Definition for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for SubscriptionDefinition
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-subscriptiondefinition.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::SubscriptionDefinition"

    Properties: SubscriptionDefinitionProperties = attrib(
        factory=SubscriptionDefinitionProperties,
        converter=create_object_converter(SubscriptionDefinitionProperties),
    )


@attrs(**ATTRSCONFIG)
class SubscriptionDefinitionVersionProperties(ResourceProperties):
    SubscriptionDefinitionId = attrib(default=None)
    Subscriptions = attrib(default=None)


@attrs(**ATTRSCONFIG)
class SubscriptionDefinitionVersion(Resource):
    """A Subscription Definition Version for Greengrass.

    See Also:
        `AWS Cloud Formation documentation for SubscriptionDefinitionVersion
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-greengrass-subscriptiondefinitionversion.html>`_
    """

    RESOURCE_TYPE = "AWS::Greengrass::SubscriptionDefinitionVersion"

    Properties: SubscriptionDefinitionVersionProperties = attrib(
        factory=SubscriptionDefinitionVersionProperties,
        converter=create_object_converter(SubscriptionDefinitionVersionProperties),
    )



"""General-use classes to interact with the Greengrass service through CloudFormation.

See Also:
    `AWS developer guide for Greengrass
    <https://docs.aws.amazon.com/greengrass/latest/developerguide/what-is-gg.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import greengrass as _raw

# noinspection PyUnresolvedReferences
from .._raw.greengrass import *



"""General-use classes to interact with the IoTThingsGraph service through CloudFormation.

See Also:
    `AWS developer guide for IoTThingsGraph
    <https://docs.aws.amazon.com/thingsgraph/latest/ug/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import iotthingsgraph as _raw

# noinspection PyUnresolvedReferences
from .._raw.iotthingsgraph import *



"""General-use classes to interact with the PinpointEmail service through CloudFormation.

See Also:
    `AWS developer guide for PinpointEmail
    <http://docs.aws.amazon.com/pinpoint/latest/userguide/welcome.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import pinpointemail as _raw

# noinspection PyUnresolvedReferences
from .._raw.pinpointemail import *



"""Raw representations of every data type in the AWS SecurityHub service.

See Also:
    `AWS developer guide for SecurityHub
    <https://docs.aws.amazon.com/securityhub/latest/userguide/index.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = ["Hub", "HubProperties"]


@attrs(**ATTRSCONFIG)
class HubProperties(ResourceProperties):
    Tags = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Hub(Resource):
    """A Hub for SecurityHub.

    See Also:
        `AWS Cloud Formation documentation for Hub
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-hub.html>`_
    """

    RESOURCE_TYPE = "AWS::SecurityHub::Hub"

    Properties: HubProperties = attrib(
        factory=HubProperties, converter=create_object_converter(HubProperties)
    )



"""General-use classes to interact with the Transfer service through CloudFormation.

See Also:
    `AWS developer guide for Transfer
    <https://docs.aws.amazon.com/transfer/latest/userguide/index.html>`_
"""

# noinspection PyUnresolvedReferences
from .._raw import transfer as _raw

# noinspection PyUnresolvedReferences
from .._raw.transfer import *



"""Raw representations of every data type in the AWS Pinpoint service.

See Also:
    `AWS developer guide for Pinpoint
    <https://docs.aws.amazon.com/pinpoint/latest/userguide/welcome.html>`_

This file is automatically generated, and should not be directly edited.
"""

from attr import attrib
from attr import attrs

from ..core import ATTRSCONFIG
from ..core import Resource
from ..core import ResourceProperties
from ..core import create_object_converter

__all__ = [
    "ADMChannel",
    "ADMChannelProperties",
    "APNSChannel",
    "APNSChannelProperties",
    "APNSSandboxChannel",
    "APNSSandboxChannelProperties",
    "APNSVoipChannel",
    "APNSVoipChannelProperties",
    "APNSVoipSandboxChannel",
    "APNSVoipSandboxChannelProperties",
    "App",
    "AppProperties",
    "ApplicationSettings",
    "ApplicationSettingsProperties",
    "BaiduChannel",
    "BaiduChannelProperties",
    "Campaign",
    "CampaignProperties",
    "EmailChannel",
    "EmailChannelProperties",
    "EventStream",
    "EventStreamProperties",
    "GCMChannel",
    "GCMChannelProperties",
    "Segment",
    "SegmentProperties",
    "SMSChannel",
    "SMSChannelProperties",
    "VoiceChannel",
    "VoiceChannelProperties",
]


@attrs(**ATTRSCONFIG)
class ADMChannelProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    ClientId = attrib(default=None)
    ClientSecret = attrib(default=None)
    Enabled = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ADMChannel(Resource):
    """A Adm Channel for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for ADMChannel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-admchannel.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::ADMChannel"

    Properties: ADMChannelProperties = attrib(
        factory=ADMChannelProperties,
        converter=create_object_converter(ADMChannelProperties),
    )


@attrs(**ATTRSCONFIG)
class APNSChannelProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    BundleId = attrib(default=None)
    Certificate = attrib(default=None)
    DefaultAuthenticationMethod = attrib(default=None)
    Enabled = attrib(default=None)
    PrivateKey = attrib(default=None)
    TeamId = attrib(default=None)
    TokenKey = attrib(default=None)
    TokenKeyId = attrib(default=None)


@attrs(**ATTRSCONFIG)
class APNSChannel(Resource):
    """A Apns Channel for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for APNSChannel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-apnschannel.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::APNSChannel"

    Properties: APNSChannelProperties = attrib(
        factory=APNSChannelProperties,
        converter=create_object_converter(APNSChannelProperties),
    )


@attrs(**ATTRSCONFIG)
class APNSSandboxChannelProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    BundleId = attrib(default=None)
    Certificate = attrib(default=None)
    DefaultAuthenticationMethod = attrib(default=None)
    Enabled = attrib(default=None)
    PrivateKey = attrib(default=None)
    TeamId = attrib(default=None)
    TokenKey = attrib(default=None)
    TokenKeyId = attrib(default=None)


@attrs(**ATTRSCONFIG)
class APNSSandboxChannel(Resource):
    """A Apns Sandbox Channel for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for APNSSandboxChannel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-apnssandboxchannel.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::APNSSandboxChannel"

    Properties: APNSSandboxChannelProperties = attrib(
        factory=APNSSandboxChannelProperties,
        converter=create_object_converter(APNSSandboxChannelProperties),
    )


@attrs(**ATTRSCONFIG)
class APNSVoipChannelProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    BundleId = attrib(default=None)
    Certificate = attrib(default=None)
    DefaultAuthenticationMethod = attrib(default=None)
    Enabled = attrib(default=None)
    PrivateKey = attrib(default=None)
    TeamId = attrib(default=None)
    TokenKey = attrib(default=None)
    TokenKeyId = attrib(default=None)


@attrs(**ATTRSCONFIG)
class APNSVoipChannel(Resource):
    """A Apns Voip Channel for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for APNSVoipChannel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-apnsvoipchannel.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::APNSVoipChannel"

    Properties: APNSVoipChannelProperties = attrib(
        factory=APNSVoipChannelProperties,
        converter=create_object_converter(APNSVoipChannelProperties),
    )


@attrs(**ATTRSCONFIG)
class APNSVoipSandboxChannelProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    BundleId = attrib(default=None)
    Certificate = attrib(default=None)
    DefaultAuthenticationMethod = attrib(default=None)
    Enabled = attrib(default=None)
    PrivateKey = attrib(default=None)
    TeamId = attrib(default=None)
    TokenKey = attrib(default=None)
    TokenKeyId = attrib(default=None)


@attrs(**ATTRSCONFIG)
class APNSVoipSandboxChannel(Resource):
    """A Apns Voip Sandbox Channel for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for APNSVoipSandboxChannel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-apnsvoipsandboxchannel.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::APNSVoipSandboxChannel"

    Properties: APNSVoipSandboxChannelProperties = attrib(
        factory=APNSVoipSandboxChannelProperties,
        converter=create_object_converter(APNSVoipSandboxChannelProperties),
    )


@attrs(**ATTRSCONFIG)
class AppProperties(ResourceProperties):
    Name = attrib(default=None)


@attrs(**ATTRSCONFIG)
class App(Resource):
    """A App for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for App
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-app.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::App"

    Properties: AppProperties = attrib(
        factory=AppProperties, converter=create_object_converter(AppProperties)
    )


@attrs(**ATTRSCONFIG)
class ApplicationSettingsProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    CampaignHook = attrib(default=None)
    CloudWatchMetricsEnabled = attrib(default=None)
    Limits = attrib(default=None)
    QuietTime = attrib(default=None)


@attrs(**ATTRSCONFIG)
class ApplicationSettings(Resource):
    """A Application Settings for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for ApplicationSettings
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-applicationsettings.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::ApplicationSettings"

    Properties: ApplicationSettingsProperties = attrib(
        factory=ApplicationSettingsProperties,
        converter=create_object_converter(ApplicationSettingsProperties),
    )


@attrs(**ATTRSCONFIG)
class BaiduChannelProperties(ResourceProperties):
    ApiKey = attrib(default=None)
    ApplicationId = attrib(default=None)
    Enabled = attrib(default=None)
    SecretKey = attrib(default=None)


@attrs(**ATTRSCONFIG)
class BaiduChannel(Resource):
    """A Baidu Channel for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for BaiduChannel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-baiduchannel.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::BaiduChannel"

    Properties: BaiduChannelProperties = attrib(
        factory=BaiduChannelProperties,
        converter=create_object_converter(BaiduChannelProperties),
    )


@attrs(**ATTRSCONFIG)
class CampaignProperties(ResourceProperties):
    AdditionalTreatments = attrib(default=None)
    ApplicationId = attrib(default=None)
    CampaignHook = attrib(default=None)
    Description = attrib(default=None)
    HoldoutPercent = attrib(default=None)
    IsPaused = attrib(default=None)
    Limits = attrib(default=None)
    MessageConfiguration = attrib(default=None)
    Name = attrib(default=None)
    Schedule = attrib(default=None)
    SegmentId = attrib(default=None)
    SegmentVersion = attrib(default=None)
    TreatmentDescription = attrib(default=None)
    TreatmentName = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Campaign(Resource):
    """A Campaign for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for Campaign
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-campaign.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::Campaign"

    Properties: CampaignProperties = attrib(
        factory=CampaignProperties,
        converter=create_object_converter(CampaignProperties),
    )


@attrs(**ATTRSCONFIG)
class EmailChannelProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    ConfigurationSet = attrib(default=None)
    Enabled = attrib(default=None)
    FromAddress = attrib(default=None)
    Identity = attrib(default=None)
    RoleArn = attrib(default=None)


@attrs(**ATTRSCONFIG)
class EmailChannel(Resource):
    """A Email Channel for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for EmailChannel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-emailchannel.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::EmailChannel"

    Properties: EmailChannelProperties = attrib(
        factory=EmailChannelProperties,
        converter=create_object_converter(EmailChannelProperties),
    )


@attrs(**ATTRSCONFIG)
class EventStreamProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    DestinationStreamArn = attrib(default=None)
    RoleArn = attrib(default=None)


@attrs(**ATTRSCONFIG)
class EventStream(Resource):
    """A Event Stream for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for EventStream
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-eventstream.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::EventStream"

    Properties: EventStreamProperties = attrib(
        factory=EventStreamProperties,
        converter=create_object_converter(EventStreamProperties),
    )


@attrs(**ATTRSCONFIG)
class GCMChannelProperties(ResourceProperties):
    ApiKey = attrib(default=None)
    ApplicationId = attrib(default=None)
    Enabled = attrib(default=None)


@attrs(**ATTRSCONFIG)
class GCMChannel(Resource):
    """A Gcm Channel for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for GCMChannel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-gcmchannel.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::GCMChannel"

    Properties: GCMChannelProperties = attrib(
        factory=GCMChannelProperties,
        converter=create_object_converter(GCMChannelProperties),
    )


@attrs(**ATTRSCONFIG)
class SMSChannelProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    Enabled = attrib(default=None)
    SenderId = attrib(default=None)
    ShortCode = attrib(default=None)


@attrs(**ATTRSCONFIG)
class SMSChannel(Resource):
    """A Sms Channel for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for SMSChannel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-smschannel.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::SMSChannel"

    Properties: SMSChannelProperties = attrib(
        factory=SMSChannelProperties,
        converter=create_object_converter(SMSChannelProperties),
    )


@attrs(**ATTRSCONFIG)
class SegmentProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    Dimensions = attrib(default=None)
    Name = attrib(default=None)
    SegmentGroups = attrib(default=None)


@attrs(**ATTRSCONFIG)
class Segment(Resource):
    """A Segment for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for Segment
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-segment.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::Segment"

    Properties: SegmentProperties = attrib(
        factory=SegmentProperties, converter=create_object_converter(SegmentProperties)
    )


@attrs(**ATTRSCONFIG)
class VoiceChannelProperties(ResourceProperties):
    ApplicationId = attrib(default=None)
    Enabled = attrib(default=None)


@attrs(**ATTRSCONFIG)
class VoiceChannel(Resource):
    """A Voice Channel for Pinpoint.

    See Also:
        `AWS Cloud Formation documentation for VoiceChannel
        <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-pinpoint-voicechannel.html>`_
    """

    RESOURCE_TYPE = "AWS::Pinpoint::VoiceChannel"

    Properties: VoiceChannelProperties = attrib(
        factory=VoiceChannelProperties,
        converter=create_object_converter(VoiceChannelProperties),
    )



import os

from setuptools import find_packages
from setuptools import setup

THIS_DIRECTORY = os.path.abspath(os.path.dirname(__file__))


def get_version_data():
    data = {}
    with open(os.path.join(THIS_DIRECTORY, "src", "flyingcircus", "_about.py")) as fp:
        exec(fp.read(), data)
    return data


def get_readme():
    with open(os.path.join(THIS_DIRECTORY, "README.md")) as fp:
        desc = fp.read()
    return desc


setup(
    # Basic Project Description
    name="flying-circus",
    version=get_version_data()["__version__"],
    description="A tool for describing AWS infrastructure as code",
    long_description=get_readme(),
    long_description_content_type="text/markdown",
    # Project Packaging
    # FIXME I think we are still packaging fcspike???
    package_dir={"": "src"},
    packages=find_packages(where="src"),  # FIXME do we need this?
    install_requires=[
        # We use the `kw_only` only for attribute classes, which was
        # introduced in v18.2.0
        "attrs>=18.2.0",
        "inflection>=0.3.1,<0.4",
        "PyYAML==5.1.1",
    ],
    # Contact Details
    author="Gary Donovan",
    author_email="gazza@gazza.id.au",
    url="https://github.com/garyd203/flying-circus",
    project_urls={
        "Documentation": "https://flying-circus.readthedocs.io/en/latest/",
        "Source": "https://github.com/garyd203/flying-circus",
        "Tracker": "https://github.com/garyd203/flying-circus/issues",
    },
    # Other metadata for PyPI
    license="LGPL v3",
    keywords="AWS cloudformation infrastructure-as-code",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Software Development :: Pre-processors",
        "Topic :: System :: Systems Administration",
    ],
    metadata_version="2.1",
)
